Cell Maps VNN (Cell Maps Visible Neural Network) Tool
================================================================


.. image:: https://img.shields.io/pypi/v/cellmaps_vnn.svg
        :target: https://pypi.python.org/pypi/cellmaps_vnn

.. image:: https://app.travis-ci.com/idekerlab/cellmaps_vnn.svg
        :target: https://app.travis-ci.com/idekerlab/cellmaps_vnn

.. image:: https://readthedocs.org/projects/cellmaps-vnn/badge/?version=latest
        :target: https://cellmaps-vnn.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

The Cell Maps VNN Tool enables the creation, training, and usage of an interpretable neural network-based models that predict cell response to a drug.
A hierarchy in `HCX <https://cytoscape.org/cx/cx2/hcx-specification/>`__ format (for instance, generated by `cellmaps_generate_hierarchy tool <https://cellmaps-generate-hierarchy.readthedocs.io/>`__)
is used to define the structure of the visible neural network.

This tool creates an output directories (separately for training, testing/prediction and annotation) where results are stored and registered
within `Research Object Crates (RO-Crate) <https://www.researchobject.org/ro-crate>`__ using
the `FAIRSCAPE-cli <https://pypi.org/project/fairscape-cli>`__.

.. warning::

    At the moment, this tool enables a user to perform training and predictions using data
    formatted for `NeST VNN <https://github.com/idekerlab/nest_vnn>`__ project. This example data is located in the
    example directory of `Cell Maps VNN GitHub Repository <https://github.com/idekerlab/cellmaps_vnn/tree/main/examples>`__.

**Overview of Cell Maps VNN Flow**

.. image:: images/cellmaps_vnn_general.png
  :alt: Overview of Cell Maps VNN

* Free software: MIT license
* Source code: https://github.com/idekerlab/cellmaps_vnn

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   inputs
   outputs
   modules
   developer
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
